<?php
/**
 * @file
 */

namespace Drupal\zsm\Plugin\views\field;

use Drupal\views\Plugin\views\field\FieldPluginBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\views\ResultRow;
use Drupal\Core\Url;
use Drupal\Core\Link;
use Drupal\Component\Utility\Html;

/**
 * Defines a views field plugin.
 *
 * @ingroup views_field_handlers
 *
 * @ViewsField("zsm_manage_enabled_plugins")
 */

class ZSMManageEnabledPluginsField extends FieldPluginBase {
  /**
   * @{inheritdoc}
   */
  public function query() {
    // Leave empty to avoid a query on this field.
  }
  /**
   * Define the available options
   * @return array
   */
  protected function defineOptions() {
    $options = parent::defineOptions();

    return $options;
  }

  /**
   * Provide the options form.
   */
  public function buildOptionsForm(&$form, FormStateInterface $form_state) {
    parent::buildOptionsForm($form, $form_state);
  }
  /**
   * {@inheritdoc}
   */
  public function render(ResultRow $values)
  {
    $data_entity = $this->getEntity($values);
    $plugins = $data_entity->get('field_zsm_enabled_plugins')->getValue();
    $ret = '';
    foreach($plugins as $plugin) {
      $plugin_edit_url = new Url('entity.' . $plugin['target_type'] . '.edit_form', array($plugin['target_type'] => $plugin['target_id']));
      $params = array('zsm_core' => $data_entity->id(), 'entity_type' => $plugin['target_type'], 'entity_id' => $plugin['target_id']);
      $plugin_remove_url = new Url('zsm.zsm_core_remove_plugin', $params);

      $p = \Drupal::entityTypeManager()->getStorage($plugin['target_type'])->load($plugin['target_id']);

      $e_link = new Link('Edit', $plugin_edit_url);
      $plugin_edit_link = $e_link->toString()->getGeneratedLink();
      $plugin_remove_link = Link::fromTextAndUrl('Remove from Monitor', $plugin_remove_url)->toString();

      $ret .= $p->label() . ': ' . $plugin_edit_link .  ' - ' . $plugin_remove_link . '<br>';
    }

    return array(
      '#markup' => $ret,
    );
  }
}